@@ -51,8 +51,8 @@ datetime
     :toctree: generated/
     :nosignatures:
 
-
-.. timestamp
+    timestamp
+    now
 
 
 decorators
@@ -64,6 +64,7 @@ decorators
 
     memoize
 
+
 functions
 ==========
 
@@ -74,6 +75,7 @@ functions
     fibonacci
     binomial_coefficient
 
+
 itertools
 =========
 
@@ -118,27 +120,6 @@ maps
     normalize_values
 
 
-mixing
-======
-
-.. autosummary::
-    :toctree: generated/
-    :nosignatures:
-
-    mix_in_functions
-    mix_in_class_attributes
-
-
-names
-=====
-
-.. autosummary::
-    :toctree: generated/
-    :nosignatures:
-
-    random_name
-
-
 profiling
 =========
 
@@ -149,6 +130,14 @@ profiling
     print_profile
 
 
+remote
+======
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+
 statistics
 ==========
 
@@ -170,6 +159,7 @@ xfunc
 
     XFunc
 
+
 """
 from __future__ import absolute_import
 from __future__ import division
@@ -193,16 +183,12 @@ from .colors import *
 from .datetime_ import *
 from .decorators import *
 from .encoders import *
+from .functions import *
 from .itertools_ import *
 from .maps import *
-from .mixing import *
-from .names import *
 from .profiling import *
 from .remote import *
-from .sorting import *
-from .xfunc import *
-from .xscript import *
-from .functions import *
 from .statistics import *
+from .xfunc import *
 
 __all__ = [name for name in dir() if not name.startswith('_')]
